@@ -32,15 +32,17 @@
 #include <QParallelAnimationGroup>
 
 AbstractClipItem::AbstractClipItem(const ItemInfo &info, const QRectF& rect, double fps) :
-        QObject(),
-        QGraphicsRectItem(rect),
-        m_info(info),
-        m_editedKeyframe(-1),
-        m_selectedKeyframe(0),
-        m_keyframeFactor(1),
-        m_keyframeOffset(0),
-        m_fps(fps),
-        m_isMainSelectedClip(false)
+        QObject()
+        , QGraphicsRectItem(rect)
+        , m_info(info)
+        , m_editedKeyframe(-1)
+        , m_selectedKeyframe(0)
+        , m_keyframeFactor(1)
+        , m_keyframeOffset(0)
+        , m_keyframeDefault(0)
+	, m_visibleParam(0)
+        , m_fps(fps)
+        , m_isMainSelectedClip(false)
 {
     setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
 #if QT_VERSION >= 0x040600
@@ -58,6 +60,7 @@ void AbstractClipItem::closeAnimation()
 #if QT_VERSION >= 0x040600
     if (!isEnabled()) return;
     setEnabled(false);
+    setFlag(QGraphicsItem::ItemIsSelectable, false);
     if (!(KGlobalSettings::graphicEffectsLevel() & KGlobalSettings::SimpleAnimationEffects)) {
         // animation disabled
         deleteLater();
@@ -258,7 +261,7 @@ GenTime AbstractClipItem::maxDuration() const
     return m_maxDuration;
 }
 
-void AbstractClipItem::drawKeyFrames(QPainter *painter, bool limitedKeyFrames)
+void AbstractClipItem::drawKeyFrames(QPainter *painter, const QTransform transformation, bool limitedKeyFrames)
 {
     if (m_keyframes.count() < 1)
         return;
@@ -282,7 +285,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, bool limitedKeyFrames)
         }
         y1 = br.bottom() - (m_keyframeDefault - m_keyframeOffset) * maxh;
         QLineF l(x1, y1, x2, y1);
-        QLineF l2 = painter->worldTransform().map(l);
+	QLineF l2 = transformation.map(l);
         painter->setPen(QColor(168, 168, 168, 180));
         painter->drawLine(l2);
         painter->setPen(QColor(108, 108, 108, 180));
@@ -303,7 +306,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, bool limitedKeyFrames)
     // make sure line begins with clip beginning
     if (!limitedKeyFrames && i.key() != start) {
         QLineF l(br.x(), y1, x1, y1);
-        l2 = painter->worldTransform().map(l);
+        l2 = transformation.map(l);
         painter->drawLine(l2);
     }
     while (i != m_keyframes.constEnd()) {
@@ -323,7 +326,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, bool limitedKeyFrames)
             y2 = br.bottom() - (i.value() - m_keyframeOffset) * maxh;
         }
         QLineF l(x1, y1, x2, y2);
-        l2 = painter->worldTransform().map(l);
+        l2 = transformation.map(l);
         painter->drawLine(l2);
         if (active) {
             const QRectF frame(l2.x1() - 3, l2.y1() - 3, 6, 6);
@@ -336,7 +339,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, bool limitedKeyFrames)
     // make sure line ends at clip end
     if (!limitedKeyFrames && x1 != br.right()) {
         QLineF l(x1, y1, br.right(), y1);
-        painter->drawLine(painter->worldTransform().map(l));
+        painter->drawLine(transformation.map(l));
     }
 
     if (active && m_keyframes.count() > 1) {
@@ -446,6 +449,21 @@ int AbstractClipItem::keyFrameNumber() const
     return m_keyframes.count();
 }
 
+int AbstractClipItem::checkForSingleKeyframe()
+{
+    // Check if we have only one keyframe
+    if (!m_keyframes.isEmpty() && m_keyframes.count() == 1) {
+	int min = (int) cropStart().frames(m_fps);
+	int max = (int)(cropStart() + cropDuration()).frames(m_fps) - 1;
+	if (m_keyframes.contains(min)) {
+	    // Add keyframe at end of clip to allow inserting a new keframe in between
+	    m_keyframes[max] = m_keyframes.value(min);
+	    return m_keyframes.value(min);
+	}
+    }
+    return -1;
+}
+
 int AbstractClipItem::addKeyFrame(const GenTime &pos, const double value)
 {
     QRectF br = sceneBoundingRect();
