@@ -80,6 +80,8 @@ public:
     void addData(const QString &id, const QString &key, const QString &data);
     void setScale(double scaleFactor, double verticalScale);
     void deleteClip(const QString &clipId);
+    /** @brief An effect was dropped on @param clip */
+    void slotDropEffect(ClipItem *clip, QDomElement effect, GenTime pos, int track);
     /** @brief Add effect to current clip */
     void slotAddEffect(QDomElement effect, GenTime pos, int track);
     void slotAddGroupEffect(QDomElement effect, AbstractGroupItem *group, AbstractClipItem *dropTarget = NULL);
@@ -103,7 +105,7 @@ public:
     void updateSceneFrameWidth();
     //QList <TrackInfo> tracksList() const;
     void setTool(PROJECTTOOL tool);
-    ClipItem *cutClip(ItemInfo info, GenTime cutTime, bool cut, bool execute = true);
+    ClipItem *cutClip(ItemInfo info, GenTime cutTime, bool cut, EffectsList oldStack = EffectsList(), bool execute = true);
     void slotSeekToPreviousSnap();
     void slotSeekToNextSnap();
     double getSnapPointForPos(double pos);
@@ -142,7 +144,7 @@ public:
     *
     * Makes sure no clip on track to lock is selected. */
     void lockTrack(int ix, bool lock, bool requestUpdate = true);
-    void groupClips(bool group = true);
+    void groupClips(bool group = true, QList<QGraphicsItem *> itemList = QList<QGraphicsItem *>(), QUndoCommand *command = NULL);
     void doGroupClips(QList <ItemInfo> clipInfos, QList <ItemInfo> transitionInfos, bool group);
     void loadGroups(const QDomNodeList &groups);
 
@@ -209,6 +211,9 @@ public:
     /** @brief Trigger a monitor refresh. */
     void monitorRefresh();
     
+    /** @brief Returns frame number of current mouse position. */
+    int getMousePos() const;
+    
 public slots:
     /** @brief Send seek request to MLT. */
     void seekCursorPos(int pos);
@@ -276,17 +281,6 @@ public slots:
     * @param group The group to rebuild */
     void rebuildGroup(AbstractGroupItem *group);
 
-    /** @brief Cuts a group into two parts.
-    * @param clips1 Clips before the cut
-    * @param transitions1 Transitions before the cut
-    * @param clipsCut Clips that need to be cut
-    * @param transitionsCut Transitions that need to be cut
-    * @param clips2 Clips behind the cut
-    * @param transitions2 Transitions behind the cut
-    * @param cutPos Absolute position of the cut
-    * @param cut true = cut, false = "uncut" */
-    void slotRazorGroup(QList <ItemInfo> clips1, QList <ItemInfo> transitions1, QList <ItemInfo> clipsCut, QList <ItemInfo> transitionsCut, QList <ItemInfo> clips2, QList <ItemInfo> transitions2, GenTime cutPos, bool cut);
-
     /** @brief Add en effect to a track.
     * @param effect The new effect xml
     * @param ix The track index */
@@ -392,6 +386,7 @@ private:
     int m_selectedTrack;
     int m_spacerOffset;
 
+    QMutex m_selectionMutex;
     QMutex m_mutex;
     QWaitCondition m_producerNotReady;
     KStatefulBrush m_activeTrackBrush;
