@@ -86,6 +86,7 @@ public:
     void checkOverlay();
     void updateTimecodeFormat();
     void updateMarkers(DocClipBase *source);
+    void setMarkers(QList <CommentedTime> markers);
     MonitorEditWidget *getEffectEdit();
     QWidget *container();
     void reloadProducer(const QString &id);
@@ -121,7 +122,6 @@ protected:
     //virtual void paintEvent(QPaintEvent * event);
 
 private:
-    Kdenlive::MONITORID m_name;
     DocClipBase *m_currentClip;
     SmallRuler *m_ruler;
     Overlay *m_overlay;
@@ -140,7 +140,6 @@ private:
     QMenu *m_markerMenu;
     QPoint m_DragStartPosition;
     MonitorEditWidget *m_effectWidget;
-    VideoContainer *m_videoBox;
     /** Selected clip/transition in timeline. Used for looping it. */
     AbstractClipItem *m_selectedClip;
     /** true if selected clip is transition, false = selected clip is clip.
