@@ -53,6 +53,9 @@ void MonitorManager::initMonitors(Monitor *clipMonitor, Monitor *projectMonitor,
 {
     m_clipMonitor = clipMonitor;
     m_projectMonitor = projectMonitor;
+    
+    connect(m_clipMonitor->render, SIGNAL(activateMonitor(Kdenlive::MONITORID)), this, SLOT(activateMonitor(Kdenlive::MONITORID)));
+    connect(m_projectMonitor->render, SIGNAL(activateMonitor(Kdenlive::MONITORID)), this, SLOT(activateMonitor(Kdenlive::MONITORID)));
 
     m_monitorsList.append(clipMonitor);
     m_monitorsList.append(projectMonitor);
@@ -81,6 +84,12 @@ AbstractMonitor* MonitorManager::monitor(Kdenlive::MONITORID monitorName)
     return monitor;
 }
 
+void MonitorManager::setConsumerProperty(const QString &name, const QString &value)
+{
+    if (m_clipMonitor) m_clipMonitor->render->setConsumerProperty(name, value);
+    if (m_projectMonitor) m_projectMonitor->render->setConsumerProperty(name, value);
+}
+
 bool MonitorManager::activateMonitor(Kdenlive::MONITORID name, bool forceRefresh)
 {
     if (m_clipMonitor == NULL || m_projectMonitor == NULL)
@@ -99,8 +108,9 @@ bool MonitorManager::activateMonitor(Kdenlive::MONITORID name, bool forceRefresh
     if (m_activeMonitor) {
         m_activeMonitor->blockSignals(true);
         m_activeMonitor->parentWidget()->raise();
+	m_activeMonitor->blockSignals(false);
         m_activeMonitor->start();
-        m_activeMonitor->blockSignals(false);
+        
     }
     emit checkColorScopes();
     return (m_activeMonitor != NULL);
