@@ -43,10 +43,11 @@ SmallRuler::SmallRuler(Monitor *monitor, Render *render, QWidget *parent) :
     m_zoneStart = 10;
     m_zoneEnd = 60;
     KSharedConfigPtr config = KSharedConfig::openConfig(KdenliveSettings::colortheme());
-    m_zoneBrush = KStatefulBrush(KColorScheme::View, KColorScheme::FocusColor, config);
+    m_zoneColor = KStatefulBrush(KColorScheme::View, KColorScheme::FocusColor, config).brush(this).color();
+    m_zoneColor.setAlpha(180);
 
     setMouseTracking(true);
-    setMinimumHeight(8);
+    setMinimumHeight(QFontInfo(font()).pixelSize());
     adjustScale(m_maxval);
 }
 
@@ -121,6 +122,7 @@ QPoint SmallRuler::zone()
 // virtual
 void SmallRuler::mousePressEvent(QMouseEvent * event)
 {
+    m_render->setActiveMonitor();
     const int pos = event->x() / m_scale;
     if (event->button() == Qt::RightButton) {
         // Right button clicked, move selection zone
@@ -148,7 +150,7 @@ void SmallRuler::mouseReleaseEvent(QMouseEvent * event)
 void SmallRuler::leaveEvent(QEvent * event)
 {
     QWidget::leaveEvent(event);
-    if (m_cursorColor == palette().highlight()) {
+    if (m_cursorColor == palette().link()) {
 	m_cursorColor = palette().text();
 	update();
     }
@@ -168,10 +170,10 @@ void SmallRuler::mouseMoveEvent(QMouseEvent * event)
     else {
 	if (m_cursorColor == palette().text() && qAbs(pos - m_cursorFramePosition) * m_scale < 7) {
 	    // Mouse is over cursor
-	    m_cursorColor = palette().highlight();
+	    m_cursorColor = palette().link();
 	    update();
 	}
-	else if (m_cursorColor == palette().highlight() && qAbs(pos - m_cursorFramePosition) * m_scale >= 7) {
+	else if (m_cursorColor == palette().link() && qAbs(pos - m_cursorFramePosition) * m_scale >= 7) {
 	    m_cursorColor = palette().text();
 	    update();
 	}
@@ -240,9 +242,7 @@ void SmallRuler::updatePixmap()
 
     const int zoneStart = (int)(m_zoneStart * m_scale);
     const int zoneEnd = (int)(m_zoneEnd * m_scale);
-    p.setPen(Qt::NoPen);
-    p.setBrush(m_zoneBrush.brush(this));
-    p.drawRect(zoneStart, 0, zoneEnd - zoneStart, height());
+    p.fillRect(zoneStart, 0, zoneEnd - zoneStart, height(), QBrush(m_zoneColor));
 
     // draw ruler
     p.setPen(palette().midlight().color());
@@ -287,21 +287,22 @@ void SmallRuler::paintEvent(QPaintEvent *e)
     int cursorPos = m_cursorFramePosition * m_scale;
     // draw pointer
     QPolygon pa(3);
-    pa.setPoints(3, cursorPos - 6, 7, cursorPos + 6, 7, cursorPos/*+0*/, 0);
+    pa.setPoints(3, cursorPos - 6, height() - 1, cursorPos + 6, height() - 1, cursorPos/*+0*/, height() - 8);
     p.setBrush(m_cursorColor);
     p.setPen(Qt::NoPen);
     p.drawPolygon(pa);
 
     // Draw seeking pointer
     if (m_lastSeekPosition != SEEK_INACTIVE && m_lastSeekPosition != m_cursorFramePosition) {
-	p.fillRect(m_lastSeekPosition * m_scale - 1, 0, 3, height(), palette().highlight());
+	p.fillRect(m_lastSeekPosition * m_scale - 1, 0, 3, height(), palette().linkVisited());
     }
 }
 
 void SmallRuler::updatePalette()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig(KdenliveSettings::colortheme());
-    m_zoneBrush = KStatefulBrush(KColorScheme::View, KColorScheme::FocusColor, config);
+    m_zoneColor = KStatefulBrush(KColorScheme::View, KColorScheme::FocusColor, config).brush(this).color();
+    m_zoneColor.setAlpha(180);
     updatePixmap();
 }
 
